@@ -1,8 +1,9 @@
 package Lemonldap::NG::Handler::Lib::OAuth2;
+use Lemonldap::NG::Common::JWT qw(getAccessTokenSessionId);
 
 use strict;
 
-our $VERSION = '2.0.8';
+our $VERSION = '2.0.12';
 
 sub retrieveSession {
     my ( $class, $req, $id ) = @_;
@@ -10,8 +11,18 @@ sub retrieveSession {
 
     # Retrieve regular session if this is not an offline access token
     unless ($offlineId) {
-        return $class->Lemonldap::NG::Handler::Main::retrieveSession( $req,
-            $id );
+        my $data =
+          $class->Lemonldap::NG::Handler::Main::retrieveSession( $req, $id );
+        if ( ref($data) eq "HASH" ) {
+            $data = { %{$data}, $class->_getTokenAttributes($req) };
+
+            # Update cache
+            $class->data($data);
+        }
+        else {
+            $req->data->{oauth2_error} = 'invalid_token';
+        }
+        return $data;
     }
 
     # 2. Get the session from cache or backend
@@ -29,7 +40,10 @@ sub retrieveSession {
 
     unless ( $session->error ) {
 
-        $class->data( $session->data );
+        my $data = { %{ $session->data }, $class->_getTokenAttributes($req) };
+
+        $class->data($data);
+
         $class->logger->debug("Get session $offlineId from Handler::Main::Run");
 
         # Verify that session is valid
@@ -48,7 +62,7 @@ sub retrieveSession {
             return 0;
         }
 
-        return $session->data;
+        return $data;
     }
     else {
         $class->logger->info("Session $offlineId can't be retrieved");
@@ -74,7 +88,29 @@ sub fetchId {
     }
 
     # Get access token session
-    my $infos = $class->getOIDCInfos($access_token);
+    my $access_token_sid = getAccessTokenSessionId($access_token);
+    unless ($access_token_sid) {
+        $req->data->{oauth2_error} = 'invalid_token';
+        return;
+    }
+    my $infos = $class->getOIDCInfos($access_token_sid);
+    unless ($infos) {
+        $req->data->{oauth2_error} = 'invalid_token';
+        return;
+    }
+
+    # Store scope and rpid for future session attributes
+    if ( $infos->{rp} ) {
+        my $rp = $infos->{rp};
+        $req->data->{_scope}         = $infos->{scope};
+        $req->data->{_clientConfKey} = $rp;
+        if (    $class->tsv->{oauth2Options}->{$rp}
+            and $class->tsv->{oauth2Options}->{$rp}->{clientId} )
+        {
+            $req->data->{_clientId} =
+              $class->tsv->{oauth2Options}->{$rp}->{clientId};
+        }
+    }
 
     # If this token is tied to a regular session ID
     if ( my $_session_id = $infos->{user_session_id} ) {
@@ -116,8 +152,21 @@ sub getOIDCInfos {
     unless ( $oidcSession->error ) {
         $class->logger->debug("Get OIDC session $id");
 
-        $infos->{user_session_id}    = $oidcSession->data->{user_session_id};
-        $infos->{offline_session_id} = $oidcSession->data->{offline_session_id};
+        # Verify that session is valid
+        unless ( $oidcSession->data->{_utime} ) {
+            $class->logger->error("_utime missing from Access Token session");
+            return;
+        }
+
+        my $ttl = $class->tsv->{timeout} - time + $oidcSession->data->{_utime};
+        $class->logger->debug( "Session TTL = " . $ttl );
+
+        if ( time - $oidcSession->data->{_utime} > $class->tsv->{timeout} ) {
+            $class->logger->info("Access Token session $id expired");
+            return;
+        }
+
+        $infos = { %{ $oidcSession->data } };
     }
     else {
         $class->logger->info("OIDC Session $id can't be retrieved");
@@ -141,4 +190,15 @@ sub goToPortal {
     return $class->HTTP_UNAUTHORIZED;
 }
 
+sub _getTokenAttributes {
+    my ( $class, $req ) = @_;
+    my %res;
+    for my $attr (qw/_scope _clientConfKey _clientId/) {
+        if ( $req->data->{$attr} ) {
+            $res{$attr} = $req->data->{$attr};
+        }
+    }
+    return %res;
+}
+
 1;
